==> cmsmadesimple-1.6.4.tgz: cms/modules/ModuleManager/lang/ext/sl_SI.php <==
<?php
$lang['use_at_your_own_risk'] = 'Uporaba na lastno odgovornost';
$lang['compatibility_disclaimer'] = 'Module, ki so tu prikazani, prispevajo razvijalci sistema CMS ter neodvisni posamezniki. Ne jamčimo, da so vsi moduli testirani, kompatibilni z va&scaron;im sistemom ali pa da v celoti delujejo. Svetujemo vam, da preberete informacije, ki jih najdete na povezavah pomoč in predstavitev pri posameznem modulu, preden ta modul namestite.';
$lang['notice'] = 'V vednost';
$lang['general_notice'] = 'Prikazane različice predstavljajo najnovej&scaron;e XML datoteke, ki so naložene v va&scaron; izbran repozitorij (navadno CMS %s). To ne pomeni, da so to zares najnovej&scaron;e različice, ki so na voljo. Svetujemo vam, da preverite, ali obstajajo morda &scaron;e kak&scaron;ne novej&scaron;e različice teh modulov. Če uporabljate privzeti repozitorij to lahko storite tako, da vpi&scaron;ete naziv modula v iskalnik na %s in kliknete gumb &amp;quot;Files&amp;quot;.';
$lang['incompatible'] = 'Ni kompatibilen';
$lang['prompt_settings'] = 'Nastavitve';
$lang['prompt_otheroptions'] = 'Ostale možnosti';
$lang['reset'] = 'Ponastavi';
$lang['error_permissions'] = '<strong><em>OPOZORILO:</em></strong> Na mapi za namestitev modulov ni dovolj pravic za namestitev. Morda imate težave s PHP varnim načinom (safe_mode). Prosimo preverite, da je varni način onemogočen in da imate ustrezne pravice na datotečnem sistemu.';
$lang['error_minimumrepository'] = 'Različica v repozitoriju ni kompatibilna s tem upraviteljem modulov';
$lang['prompt_reseturl'] = 'Ponastavi URL na privzeti';
$lang['prompt_resetcache'] = 'Osveži lokalni predpomnilnik podatkov z repozitorija';
$lang['prompt_dl_chunksize'] = 'Velikost paketa prenosa (Kb)';
$lang['text_dl_chunksize'] = 'Največja velikost podatkov za prenos s strežnika v enem paketu (ob namestitvi modula)';
$lang['error_nofilesize'] = 'Parameter filesize ni podan';
$lang['error_nofilename'] = 'Parameter filename ni podan';
$lang['error_checksum'] = 'Checksum napaka. To najverjetneje pomeni, da je datoteka po&scaron;kodovana. Do po&scaron;kodbe datoteke lahko pride pri nalaganju v repozitorij ali pa ob prenosu na va&scaron; strežnik.';
$lang['cantdownload'] = 'Ne morem prenesti';
$lang['download'] = 'Prenesi in namesti';
$lang['error_moduleinstallfailed'] = 'Namestitev modula ni uspe&scaron;na';
$lang['error_connectnomodules'] = 'Povezava je bila uspe&scaron;no vzpostavljena v izbran repozitorij, vendar kaže, da ta repozitorij ne vsebuje nobenih modulov.';
$lang['submit'] = 'Po&scaron;lji';
$lang['text_repository_url'] = 'URL naslov naj bo oblike http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL naslov repozitorija modulov:';
$lang['availmodules'] = 'Moduli na voljo';
$lang['preferences'] = 'Nastavitve';
$lang['preferencessaved'] = 'Nastavitve shranjene';
$lang['repositorycount'] = 'Najdeni moduli v repozitoriju';
$lang['instcount'] = 'Trenutno name&scaron;čeni moduli';
$lang['availablemodules'] = 'Trenuten status modulov, ki so na voljo v trenutnem repozitoriju';
$lang['helptxt'] = 'Pomoč';
$lang['abouttxt'] = 'Predstavitev';
$lang['xmltext'] = 'XML datoteka';
$lang['nametext'] = 'Naziv modula';
$lang['vertext'] = 'Različica';
$lang['sizetext'] = 'Velikost (Kb)';
$lang['statustext'] = 'Status/Akcija';
$lang['uptodate'] = 'Name&scaron;čen';
$lang['install'] = 'namestitev';
$lang['newerversion'] = 'Name&scaron;čena je novej&scaron;a različica';
$lang['onlynewesttext'] = 'Prikaži samo najnovej&scaron;o različico';
$lang['upgrade'] = 'Posodobi';
$lang['error_nosoapconnect'] = 'Ne morem vzpostaviti povezavo na SOAP strežnik';
$lang['error_soaperror'] = 'SOAP težava';
$lang['error_norepositoryurl'] = 'URL repozitorija modulov ni bil določen';
$lang['friendlyname'] = 'Upravitelj modulov';
$lang['postinstall'] = 'Upravitelj modulov je bil uspe&scaron;no name&scaron;čen';
$lang['postuninstall'] = 'Upravitelj modulov je bil uspe&scaron;no odstranjen. Uporabniki nimajo več možnosti namestitve modulov iz oddaljenega repozitorija. Lokalne namestitve so &scaron;e vedno možne.';
$lang['really_uninstall'] = 'Ste prepričani, da želite odstraniti? S tem boste zmanj&scaron;ali funkcionalnost sistema.';
$lang['uninstalled'] = 'Modul odstranjen.';
$lang['installed'] = 'Modul različice %s name&scaron;čen.';
$lang['upgraded'] = 'Modul nadgrajen na različico %s.';
$lang['moddescription'] = 'Klient za repozitorij modulov; modul omogoča predogled ter namestitev modulov iz oddaljenih strani brez potrebe po FTP povezavi ali ekstrahiranju paketov. XML datoteke modulov so prene&scaron;ene preko SOAP protokola, preverjene in avtomatično name&scaron;čene.';
$lang['error'] = 'Napaka!';
$lang['admindescription'] = 'Orodje za prenos in namestitev modulov iz oddaljenih strežnikov.';
$lang['accessdenied'] = 'Dostop zavrnjen. Prosimo, preverite va&scaron;e pravice.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.587959277.1217433595.1218876433.1218884702.10';
$lang['utmz'] = '156861353.1218827009.7.4.utmccn=(organic)|utmcsr=google|utmctr=cms made simple email obfuscate|utmcmd=organic';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/ModuleManager/lang/ext/sl_SI.php <==
<?php
$lang['available_updates'] = 'Moduli na voljo za posodobitev';
$lang['all_modules_up_to_date'] = 'Trenutno ni novej&scaron;ih modulov na voljo v repozitoriju';
$lang['error_module_object'] = 'Napaka: ne morem prenesti modula %s';
$lang['error_nomatchingmodules'] = 'Napaka: noben modul v repozitoriju ne ustreza';
$lang['error_nomodules'] = 'Napaka: ne morem pridobiti seznama name&scaron;čenih modulov';
$lang['upgrade_available'] = 'Na voljo je nova različica (%s), vi uporabljate staro različico (%s)';
$lang['newversions'] = 'Nadgradnje na voljo';
$lang['error_depends'] = 'Za namestitev morate namestiti tudi enega ali več odvisnih modulov';
$lang['msg_nodependencies'] = 'Ta datoteka ni odvisna od drugih modulov';
$lang['dependstxt'] = 'Odvisnosti';
$lang['use_at_your_own_risk'] = 'Uporaba na lastno odgovornost';
$lang['compatibility_disclaimer'] = 'Module, ki so tu prikazani, prispevajo razvijalci sistema CMS ter neodvisni posamezniki. Ne jamčimo, da so vsi moduli testirani, kompatibilni z va&scaron;im sistemom ali pa da v celoti delujejo. Svetujemo vam, da preberete informacije, ki jih najdete na povezavah pomoč in predstavitev pri posameznem modulu, preden ta modul namestite.';
$lang['notice'] = 'V vednost';
$lang['general_notice'] = 'Prikazane različice predstavljajo najnovej&scaron;e XML datoteke, ki so naložene v va&scaron; izbran repozitorij (navadno CMS %s). To ne pomeni, da so to zares najnovej&scaron;e različice, ki so na voljo. Svetujemo vam, da preverite, ali obstajajo morda &scaron;e kak&scaron;ne novej&scaron;e različice teh modulov. Če uporabljate privzeti repozitorij to lahko storite tako, da vpi&scaron;ete naziv modula v iskalnik na %s in kliknete gumb &amp;quot;Files&amp;quot;.';
$lang['incompatible'] = 'Ni kompatibilen';
$lang['prompt_settings'] = 'Nastavitve';
$lang['prompt_otheroptions'] = 'Ostale možnosti';
$lang['reset'] = 'Ponastavi';
$lang['error_permissions'] = '<strong><em>OPOZORILO:</em></strong> Na mapi za namestitev modulov ni dovolj pravic za namestitev. Morda imate težave s PHP varnim načinom (safe_mode). Prosimo preverite, da je varni način onemogočen in da imate ustrezne pravice na datotečnem sistemu.';
$lang['error_minimumrepository'] = 'Različica v repozitoriju ni kompatibilna s tem upraviteljem modulov';
$lang['prompt_reseturl'] = 'Ponastavi URL na privzeti';
$lang['prompt_resetcache'] = 'Osveži lokalni predpomnilnik podatkov z repozitorija';
$lang['prompt_dl_chunksize'] = 'Velikost paketa prenosa (Kb)';
$lang['text_dl_chunksize'] = 'Največja velikost podatkov za prenos s strežnika v enem paketu (ob namestitvi modula)';
$lang['error_nofilesize'] = 'Parameter filesize ni podan';
$lang['error_nofilename'] = 'Parameter filename ni podan';
$lang['error_checksum'] = 'Checksum napaka. To najverjetneje pomeni, da je datoteka po&scaron;kodovana. Do po&scaron;kodbe datoteke lahko pride pri nalaganju v repozitorij ali pa ob prenosu na va&scaron; strežnik.';
$lang['cantdownload'] = 'Ne morem prenesti';
$lang['download'] = 'Prenesi in namesti';
$lang['error_moduleinstallfailed'] = 'Namestitev modula ni uspe&scaron;na';
$lang['error_connectnomodules'] = 'Povezava je bila uspe&scaron;no vzpostavljena v izbran repozitorij, vendar kaže, da ta repozitorij ne vsebuje nobenih modulov.';
$lang['submit'] = 'Po&scaron;lji';
$lang['text_repository_url'] = 'URL naslov naj bo oblike http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL naslov repozitorija modulov:';
$lang['availmodules'] = 'Moduli na voljo';
$lang['preferences'] = 'Nastavitve';
$lang['preferencessaved'] = 'Nastavitve shranjene';
$lang['repositorycount'] = 'Najdeni moduli v repozitoriju';
$lang['instcount'] = 'Trenutno name&scaron;čeni moduli';
$lang['availablemodules'] = 'Trenuten status modulov, ki so na voljo v trenutnem repozitoriju';
$lang['helptxt'] = 'Pomoč';
$lang['abouttxt'] = 'Predstavitev';
$lang['xmltext'] = 'XML datoteka';
$lang['nametext'] = 'Naziv modula';
$lang['vertext'] = 'Različica';
$lang['sizetext'] = 'Velikost (Kb)';
$lang['statustext'] = 'Status/Akcija';
$lang['uptodate'] = 'Name&scaron;čen';
$lang['install'] = 'namestitev';
$lang['newerversion'] = 'Name&scaron;čena je novej&scaron;a različica';
$lang['onlynewesttext'] = 'Prikaži samo najnovej&scaron;o različico';
$lang['upgrade'] = 'Posodobi';
$lang['error_nosoapconnect'] = 'Ne morem vzpostaviti povezavo na SOAP strežnik';
$lang['error_soaperror'] = 'SOAP težava';
$lang['error_norepositoryurl'] = 'URL repozitorija modulov ni bil določen';
$lang['friendlyname'] = 'Upravitelj modulov';
$lang['postinstall'] = 'Upravitelj modulov je bil uspe&scaron;no name&scaron;čen';
$lang['postuninstall'] = 'Upravitelj modulov je bil uspe&scaron;no odstranjen. Uporabniki nimajo več možnosti namestitve modulov iz oddaljenega repozitorija. Lokalne namestitve so &scaron;e vedno možne.';
$lang['really_uninstall'] = 'Ste prepričani, da želite odstraniti? S tem boste zmanj&scaron;ali funkcionalnost sistema.';
$lang['uninstalled'] = 'Modul odstranjen.';
$lang['installed'] = 'Modul različice %s name&scaron;čen.';
$lang['upgraded'] = 'Modul nadgrajen na različico %s.';
$lang['moddescription'] = 'Klient za repozitorij modulov; modul omogoča predogled ter namestitev modulov iz oddaljenih strani brez potrebe po FTP povezavi ali ekstrahiranju paketov. XML datoteke modulov so prene&scaron;ene preko SOAP protokola, preverjene in avtomatično name&scaron;čene.';
$lang['error'] = 'Napaka!';
$lang['admindescription'] = 'Orodje za prenos in namestitev modulov iz oddaljenih strežnikov.';
$lang['accessdenied'] = 'Dostop zavrnjen. Prosimo, preverite va&scaron;e pravice.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.1722464354432002000.1251370098.1268214497.1270023141.28';
$lang['utmz'] = '156861353.1270023141.28.22.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
$lang['qca'] = 'P0-1580489763-1251370099388';
$lang['utmb'] = '156861353.3.10.1270023141';
$lang['utmc'] = '156861353';
?>
